#include "mainwindow.h"

MyPushButton::MyPushButton (QWidget *parent)
    : QPushButton (parent)
{}

MyPushButton::MyPushButton (const QString &text, QWidget *parent)
    : QPushButton (text, parent)
{}

MyPushButton::MyPushButton (int value, const QString &text, QWidget *parent)
    : QPushButton (text, parent)
{
    position = value;
}

void MyPushButton::setPosition(int value)
{
    position = value;
}

int MyPushButton::getPosition()
{
    return position;
}

MyPushButton::~MyPushButton()
{}

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    //setFixedSize(200, 120);

    QPushButton *quit = new QPushButton(tr("Quit"), this);
    //quit->setGeometry(62, 40, 75, 30);
    quit->setFont(QFont("Times", 18, QFont::Bold));

    lcd = new QLCDNumber(2);
    lcd->setSegmentStyle(QLCDNumber::Filled);

    QSlider *slider = new QSlider(Qt::Horizontal);
    slider->setRange(0, 99);
    slider->setValue(0);

    connect(quit, SIGNAL(clicked()), qApp, SLOT(quit()));
    connect(slider, SIGNAL(valueChanged(int)),
            lcd, SLOT(display(int)));

    QVBoxLayout *layout = new QVBoxLayout;
    layout->addWidget(quit);
    layout->addWidget(lcd);
    layout->addWidget(slider);

    for (int i = 0 ; i < NUMBUTTONS ; ++i)
    {
        QString num;
        num.setNum (i);
        buttons[i] = new MyPushButton (i, num, this);
        layout->addWidget(buttons[i]);
        connect (buttons[i], SIGNAL(clicked()), this, SLOT(buttonPressed()));
    }

    // add the layout to the MainWindow
    QWidget *cw = new QWidget;
    cw->setLayout(layout);
    setCentralWidget(cw);
}

MainWindow::~MainWindow()
{

}

void MainWindow::buttonPressed()
{
    MyPushButton *pb = qobject_cast <MyPushButton *> (sender());

    lcd->display(pb->getPosition());
}
